function [Peigne, NouveauRetard] = PeigneDirac(TempsFenetre, fe, Fo, retard, variance, coeffs);

% Cette fonction gnre un peigne de Dirac de frquence Fo, chantillon  la frquence fe
% et de variance donne en paramtre. Le peigne est ensuite filtr par un filtre AR dont les coefficients
% sont donns dans coeffs. Notons que le premier pic de Dirac du peigne est plac suivant un calcul de retard.

Te = 1/fe ; 						% priode d'chantillonnage
To = 1/Fo ; 						% priode du peigne de Dirac
EcartEntrePic = round(To/Te) ;% Nbre de points entre les pics de Dirac du peigne

t_wind = round(TempsFenetre * fe) ; % Nbre de points d'une fentre

temp = zeros(1,t_wind);             % gnration d'un vecteur de zros de longueur t_wind

if (retard >= EcartEntrePic)  % Si le retard est plus important que la priode du peigne, on oublie le retard
   i = 1;
else
   i = (EcartEntrePic-retard); % Sinon, on place le premier pic en fonction de ce retard
end

while (i<=t_wind)					 % Puis on place successivement les pics suivants en fonction du 1er pic
   temp(i) = 1;
   i = i + EcartEntrePic;
end

NouveauRetard = t_wind - ( i - EcartEntrePic ); % Calcul du nouveau retard en fonction du dernier pic plac

if (temp(1)==0)
   temp = [ 1, zeros(1,retard), temp ];			% Ajout d'un pic supplmentaire au dbut pour viter l'effet de clipping
end

if (temp(end)==0)											% Ajout d'un pic supplmentaire  la fin pour viter l'effet de clipping
   temp = [ temp, zeros(1,EcartEntrePic-NouveauRetard-1), 1];
end

PeigneVariance = cov(temp); 							% Calcul de la variance du peigne de Dirac non filtr
gain = 1;													% Initialisation du gain  1 pour certains cas

if (PeigneVariance ~= 0)
   gain = sqrt(variance/PeigneVariance);			% Calcul du gain  appliquer au peigne gnr
end

Peigne = filter(1, coeffs, temp*gain);				% Filtrage du peigne par le filtre AR dont les coefficients sont donns

if ( length(Peigne)>t_wind )
   Peigne = Peigne(retard+1:end-(EcartEntrePic-NouveauRetard)); % On rcupre le signal de taille originale
end